@@ -1,7 +1,7 @@
 package Date::Baha::i;
 
 use strict;
-use vars qw($VERSION); $VERSION = '0.09';
+use vars qw($VERSION); $VERSION = '0.10';
 use base qw(Exporter);
 use vars qw(@EXPORT @EXPORT_OK);
 @EXPORT = @EXPORT_OK = qw(
@@ -10,15 +10,12 @@ use vars qw(@EXPORT @EXPORT_OK);
     date
     days
     days_of_the_week
-    greg_to_bahai
     holy_days
     months
     next_holy_day
     years
 );
 
-# XXX Temporary fix for the broken Date::Calc::Date_to_Time
-use Time::Local;
 use Date::Calc qw(
     leap_year
     Add_Delta_Days
@@ -121,26 +118,28 @@ sub holy_days { return HOLY_DAYS }
 sub date {
     my %args = @_;
 
-    my ($year, $month, $day);
+    my ($year, $month, $day) = @args{qw(year month day)};
 
-    if ($args{use_gmtime}) {
-        ($year, $month, $day) = $args{timestamp}
-            ? (gmtime($args{timestamp}))[5,4,3]
-            : (gmtime)[5,4,3];
-    }
-    else {
-        ($year, $month, $day) = $args{timestamp}
-            ? (localtime($args{timestamp}))[5,4,3]
-            : (localtime)[5,4,3];
+    unless ($year && $month && $day) {
+        if ($args{use_gmtime}) {
+            ($year, $month, $day) = $args{timestamp}
+                ? (gmtime($args{timestamp}))[5,4,3]
+                : (gmtime)[5,4,3];
+        }
+        else {
+            ($year, $month, $day) = $args{timestamp}
+                ? (localtime($args{timestamp}))[5,4,3]
+                : (localtime)[5,4,3];
+        }
+
+        # Fix the year and the month.
+        $year += ADJUST_YEAR;
+        $month++;
     }
 
     # This is what will eventually be used in the return.
     my ($bahai_month, $bahai_day);
 
-    # Fix the year and the month.
-    $year += ADJUST_YEAR;
-    $month++;
-
     # Begin with the first month of the year (at the Spring equinox).
     my ($m, $d) = (MARCH, YEAR_START_DAY);
 
@@ -194,23 +193,6 @@ sub date {
 }
 # }}}
 
-# greg_to_bahai function {{{
-# XXX Whoa. Check this out:
-#perl -MTime::Local -wle'print scalar localtime timelocal(0,0,0,28,3,103)'
-#Mon Apr 28 00:00:00 2003
-#perl -MDate::Calc=Date_to_Time -wle'print scalar localtime Date_to_Time(2003,4,28,0,0,0)'
-#Sun Apr 27 19:00:00 2003
-# Conclusion: Date_to_Time sucks.
-sub greg_to_bahai {
-    my ($y, $m, $d, %args) = @_;
-    return date (
-#        timestamp => Date_to_Time ($y, $m, $d, 0, 0, 0),
-        timestamp => timelocal (0, 0, 0, $d, $m - 1, $y - ADJUST_YEAR),
-        %args
-    );
-}
-# }}}
-
 # as_string function {{{
 # XXX With Lingua::Num2Word, naively assume that we only care about English.
 sub as_string {
@@ -473,10 +455,12 @@ Date::Baha::i - Compute the numeric and named Baha'i date.
   use Date::Baha'i;
 
   %bahai_date = date ();
-  $bahai_date = date ();
-
-  %bahai_date = greg_to_bahai ($year, $month, $day);
-  $bahai_date = greg_to_bahai ($year, $month, $day);
+  %bahai_date = date (timestamp => time);
+  $bahai_date = date (
+      year  => $year,
+      month => $month,
+      day   => $day,
+  );
 
   $bahai_date = as_string (\%bahai_date);
 
@@ -712,7 +696,7 @@ L<http://www.moonwise.co.uk/year/159bahai.htm>
 =head2 date
 
   %bahai_date = date (
-      timestamp => $timestamp,
+      timestamp  => $secs_since_1970,
       use_gmtime => $use_gmtime,
       %args,
   )
@@ -741,26 +725,6 @@ with the following keys:
   timezone
   holy_day
 
-* This function currently uses the Time::Local module and as such is
-limited to dates before the 2nd of January, 2038.
-
-=head2 greg_to_bahai
-
-  %bahai_date = greg_to_bahai (
-      $year, $month, $day,
-      use_gmtime => $use_gmtime,
-      %args,
-  );
-
-Compute the Baha'i date from a Gregorian year, month, day triple.
-Also, this function can be forced to use gmtime instead of localtime 
-(the default).  The extra arguments are used for the as_string () 
-function, detailed below.
-
-In a scalar context, this function returns a string sentence with the 
-numeric and named Baha'i date.  In an array context, it returns the 
-date () hash (described above).
-
 =head2 as_string
 
   $date = as_string (
@@ -880,8 +844,6 @@ observed.  These dates are currently in standard (non-Baha'i) format.
 
 =head1 DEPENDENCIES
 
-L<Time::Local>
-
 L<Date::Calc>
 
 L<Lingua::EN::Numbers::Ordinate>
@@ -890,11 +852,9 @@ L<Lingua::Num2Word>
 
 =head1 TO DO
 
-Replace Time::Local with something that doesn't have a range limit.
+Convert to standard dates and Unix time stamps from Baha'i dates.
 
-Convert to Gregorian dates and Unix time stamps from Baha'i dates.
-
-Optonally output unicode.
+Optionally output unicode.
 
 Base the date computation on the time of day (the Baha'i day begins at 
 Sunset) - and the location longitude/latitude.  Yes, that would be 
